<img src="https://drive.google.com/uc?id=1-gMyDsJZ56TlJ84yoMfHp5OwxFzsn6wS" width=200 height=200 />

# kora

This is a collection of tools to make programming on [Google Colab](https://colab.research.google.com) easier.

This project is supported by [![AIResearch](https://airesearch.in.th/assets/img/logo/airesearch-logo.svg)](https://airesearch.in.th/)
